Index: src/gpu/GrAllocator.h |
diff --git a/src/gpu/GrAllocator.h b/src/gpu/GrAllocator.h |
index 64f6533be410def4b77c65fa262944808226f274..c5d2dc3d38a53d807466dffafb3b0b8a67779202 100644 |
--- a/src/gpu/GrAllocator.h |
+++ b/src/gpu/GrAllocator.h |
@@ -29,7 +29,7 @@ public: |
GrAllocator(size_t itemSize, int itemsPerBlock, void* initialBlock) |
: fItemSize(itemSize) |
, fItemsPerBlock(itemsPerBlock) |
- , fOwnFirstBlock(NULL == initialBlock) |
+ , fOwnFirstBlock(nullptr == initialBlock) |
, fCount(0) |
, fInsertionIndexInBlock(0) { |
SkASSERT(itemsPerBlock > 0); |
@@ -192,7 +192,7 @@ public: |
protected: |
/** |
* Set first block of memory to write into. Must be called before any other methods. |
* This requires that you have passed NULL in the constructor. |
* |
* @param initialBlock optional memory to use for the first block. |
* Must be at least itemSize*itemsPerBlock sized. |
@@ -237,7 +237,7 @@ public: |
* @param itemsPerBlock the number of items to allocate at once |
*/ |
explicit GrTAllocator(int itemsPerBlock) |
- : fAllocator(sizeof(T), itemsPerBlock, NULL) {} |
+ : fAllocator(sizeof(T), itemsPerBlock, nullptr) {} |
/** |
* Adds an item and returns it. |
@@ -192,7 +192,7 @@ public: |
/** |
* Set first block of memory to write into. Must be called before any other methods. |
- * This requires that you have passed NULL in the constructor. |
+ * This requires that you have passed nullptr in the constructor. |
* |
* @param initialBlock optional memory to use for the first block. |